@@ -166,7 +166,9 @@ class EntryBlock(Mocker, blocks.StructBlock):
     svg_bg_position = BackgroundPositionChoiceBlock(
         required=False,
         default=constants.BACKROUND_POSITION_CENTER,
+        label="Bg Position"
     )
+    bg_layer = blocks.BooleanBlock(default=False, required=False)
     container = ContainerChoiceBlock(required=False)
     padding_top = blocks.BooleanBlock(default=True, required=False)
     padding_bottom = blocks.BooleanBlock(default=True, required=False)
