@@ -246,15 +246,39 @@ const BgSlide = {
   init: () => {
     const io = new IntersectionObserver(entries => entries.forEach((item) => {
       const element = item.target;
+      const slides = element.querySelectorAll('.bg-container-item');
       if (item.isIntersecting) {
-        for (let i = 0; i < element.children.length; i++) {
-          const child = element.children[i];
-          if (child.getAttribute('data-src')) {
-            setTimeout(() => {
-              child.style.backgroundImage = `url(${child.dataset.src})`;
-              child.classList.add('anim');
-            }, 4500 * i);
+        const isSlider = element.classList.contains('slider');
+        if (!isSlider) {
+          for (let i = 0; i < slides.length; i++) {
+            if (slides[i].getAttribute('data-src')) {
+              setTimeout(() => {
+                slides[i].style.backgroundImage = `url(${slides[i].dataset.src})`;
+                slides[i].classList.add('anim');
+              }, 4500 * i);
+            }
           }
+        } else {
+          let i = 0;
+          const left = element.querySelector('.left');
+          const right = element.querySelector('.right');
+          function resfresh() {
+            console.log(i);
+            for (let i = 0; i < slides.length; i++) {
+              slides[i].style.backgroundImage = '';
+            }
+            slides[i].style.backgroundImage = `url(${slides[i].dataset.src})`;
+          }
+          console.log(slides[i])
+          slides[i].style.backgroundImage = `url(${slides[i].dataset.src})`;
+          right.addEventListener('click', (e) => {
+            i = i >= slides.length - 1 ? 0 : i + 1;
+            resfresh();
+          });
+          left.addEventListener('click', (e) => {
+            i = i === 0 ? slides.length - 1 : i - 1;
+            resfresh();
+          });
         }
         io.unobserve(element);
       }
